@@ -36,7 +36,6 @@ impl Api {
         let token = token.map(String::from).map(SecretString::new);
         let connect_timeout = time::Duration::from_secs(5);
 
-        let management = management.trim().trim_end_matches('/');
         let base = if management.starts_with("http") {
             format!("{}{}", management, prefix)
         } else if management.starts_with("api.") && management.ends_with(".statehub.io") {
@@ -65,6 +64,7 @@ impl Api {
     pub(crate) async fn is_unauthorized(&self) -> bool {
         self.head("/clusters")
             .await
+            // .inspect_err(|e| println!("{}", e))
             .err()
             .and_then(|e| e.downcast::<reqwest::Error>().ok())
             .and_then(|e| e.status())
@@ -323,7 +323,8 @@ impl Api {
             .inspect()
             .retry()
             .await?
-            .error_for_status2()
+            .error_for_status()?
+            .bytes()
             .await?
             .try_into()
             .inspect(|output| self.inspect(output))
